@@ -47,6 +47,9 @@ class Client:
                             recvData += "]"
                         elif "}" + self.seq in recvData:
                             recvData = "[" + recvData.replace(self.seq, "") + "]"
+                        else:
+                            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cNot authenticated data: " + recvData)
+                            continue
                         recvData = json.loads(recvData)
                         for data in recvData:
                             if data["METHOD"] == "AUTHENTICATION_FAILED":
