@@ -44,6 +44,9 @@ class Server:
                             recvData += "]"
                         elif "}" + self.seq in recvData:
                             recvData = "[" + recvData.replace(self.seq, "") + "]"
+                        else:
+                            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cNot authenticated data: " + recvData)
+                            continue
                         recvData = json.loads(recvData)
                         for data in recvData:
                             if data["METHOD"] == "AUTHENTICATION":
@@ -64,7 +67,7 @@ class Server:
                                         logger.log("§8[§eSERVER§8] §r[IN] " + data["METHOD"])
                                     events.call("ON_RECEIVE", [self, client, clientSocket, data])
                                 else:
-                                    logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cNot authenticated Package: " + data["METHOD"])
+                                    logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cNot authenticated package: " + data["METHOD"])
                 except Exception as e:
                     logger.log("§8[§eCLIENT§8] §8[§cWARNING§8] §cException: " + str(e) + " while receiving: " + lastData)
                     break
